@@ -2,7 +2,9 @@ import { LoaderCircle } from "lucide-react";
 
 export default function Loading({
 	loadingText = "Loading...",
-}: { loadingText?: React.ReactNode }) {
+}: {
+	loadingText?: React.ReactNode;
+}) {
 	return (
 		<div className="flex flex-col items-center justify-center h-full w-full space-y-4">
 			<LoaderCircle className="h-10 w-10 animate-spin" />
