@@ -13,11 +13,7 @@ import { HNavBar, VStack } from "@/components/layout";
 import { ScrollableCardTable } from "@/components/ScrollableCardTable";
 import { Button } from "@/components/ui/button";
 import { Checkbox } from "@/components/ui/checkbox";
-import {
-	DialogDescription,
-	DialogFooter,
-	DialogTitle,
-} from "@/components/ui/dialog";
+import { DialogFooter, DialogTitle } from "@/components/ui/dialog";
 import {
 	DropdownMenu,
 	DropdownMenuContent,
@@ -359,13 +355,13 @@ function RemoveRepositoryDialog({
 	return (
 		<>
 			<DialogTitle>{tc("vpm repositories:remove repository")}</DialogTitle>
-			<DialogDescription>
+			<div>
 				<p className={"whitespace-normal font-normal"}>
 					{tc("vpm repositories:dialog:confirm remove description", {
 						name: displayName,
 					})}
 				</p>
-			</DialogDescription>
+			</div>
 			<DialogFooter>
 				<Button onClick={() => dialog.close()}>
 					{tc("general:button:cancel")}
