@@ -1,11 +1,7 @@
 import type React from "react";
 import { useEffect, useRef, useState } from "react";
 import { Button } from "@/components/ui/button";
-import {
-	DialogDescription,
-	DialogFooter,
-	DialogTitle,
-} from "@/components/ui/dialog";
+import { DialogFooter, DialogTitle } from "@/components/ui/dialog";
 import { Progress } from "@/components/ui/progress";
 import type { TauriCreateBackupProgress } from "@/lib/bindings";
 import { commands } from "@/lib/bindings";
@@ -69,7 +65,7 @@ export function BackupProjectDialog({
 	return (
 		<div className={"contents whitespace-normal"}>
 			<DialogTitle>{header ?? tc("projects:dialog:backup header")}</DialogTitle>
-			<DialogDescription>
+			<div>
 				<p>{tc("projects:dialog:creating backup...")}</p>
 				<p>
 					{tc("projects:dialog:proceed k/n", {
@@ -81,7 +77,7 @@ export function BackupProjectDialog({
 					{progress.last_proceed || "Collecting files..."}
 				</p>
 				<Progress value={progress.proceed} max={progress.total} />
-			</DialogDescription>
+			</div>
 			<DialogFooter>
 				<Button className="mr-1" onClick={() => cancelRef.current?.()}>
 					{tc("general:button:cancel")}
