@@ -1,21 +1,17 @@
+import { useState } from "react";
 import { Button } from "@/components/ui/button";
 import { Checkbox } from "@/components/ui/checkbox";
+import { DialogFooter, DialogTitle } from "@/components/ui/dialog";
 import {
-	DialogDescription,
-	DialogFooter,
-	DialogTitle,
-} from "@/components/ui/dialog";
-import {
+	commands,
 	type TauriImportDuplicated,
 	type TauriImportTemplateResult,
-	commands,
 } from "@/lib/bindings";
 import { dateToString } from "@/lib/dateToString";
 import { type DialogContext, openSingleDialog } from "@/lib/dialog";
 import { tc, tt } from "@/lib/i18n";
 import { queryClient } from "@/lib/query-client";
 import { toastSuccess } from "@/lib/toast";
-import { useState } from "react";
 
 export async function processResult(result: TauriImportTemplateResult) {
 	await queryClient.invalidateQueries({
@@ -75,7 +71,7 @@ export function AskOverride({
 	return (
 		<>
 			<DialogTitle>{tc("templates:dialog:duplicated")}</DialogTitle>
-			<DialogDescription className={"flex flex-col gap-2"}>
+			<div className={"flex flex-col gap-2"}>
 				<p className={"whitespace-normal font-normal"}>
 					{tc("templates:dialog:confirm update templates")}
 				</p>
@@ -132,7 +128,7 @@ export function AskOverride({
 						);
 					})}
 				</ul>
-			</DialogDescription>
+			</div>
 			<DialogFooter>
 				<Button
 					onClick={() => {
