@@ -62,7 +62,7 @@ impl VccDatabaseConnection {
 
     pub async fn save(&self, io: &DefaultEnvironmentIo) -> io::Result<()> {
         // nop for now but might have to do something in the future
-        io.write_sync(FILE_NAME.as_ref(), &self.db.serialize())
+        io.write_atomic(FILE_NAME.as_ref(), &self.db.serialize())
             .await?;
         Ok(())
     }
